import { ElementRef, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
export declare class PictureComponent implements OnChanges {
    private eRef;
    /**
     * Define de width of the image.
     */
    width: string;
    /**
     * Define de height of the image.
     */
    height: string;
    /**
     * Define the default image, when no image set yet.
     */
    defaultImage: any;
    /**
     * Define the image to show.
     */
    image: any;
    /**
     * Define if want rounded image.
     */
    rounded: boolean;
    /**
     * Define if user only can see the image.
     */
    onlyViewImage: boolean;
    /**
     * Define if user can edit image.
     */
    showEditImage: boolean;
    /**
     * Define if user can upload image.
     */
    showUploadImage: boolean;
    /**
     * Define if user can remove image.
     */
    showRemoveImage: boolean;
    /**
     * Define if user can view image, to remove options on modals.
     */
    showViewImage: boolean;
    /**
     * Define if upload image icon shows
     */
    showUpIcon: boolean;
    /**
     * Define size of the uploado image icon
     */
    UpIconSize: string;
    /**
     * Emitte the image uploaded.
     */
    uploadedImage: EventEmitter<File>;
    /**
     * Emitte the signal to delete image.
     */
    deleteImage: EventEmitter<any>;
    /**
     * Variable to control the overlay hover image.
     */
    showOverlay: boolean;
    /**
     * Variable to control if show or not the options.
     */
    showDropdown: boolean;
    /**
     * Variable to set the image when user choose image from system.
     */
    imageChangedEvent: any;
    /**
     * Variable to control modal image cropper.
     */
    openImgCropper: boolean;
    /**
     * Variable to control modal image viewer.
     */
    openImgViewer: boolean;
    /**
     * Variable to set imaged cropped for edit again image cropped.
     */
    savedImageCropped: any;
    /**
     * variable to set the name and extention of the image.
     */
    originalFileNameType: {
        name: string;
    };
    /**
     * Variable to set the initial position of the dropdown,
     * and used on template.
     */
    pictureDropdownPosition: {
        top: string;
        left: string;
    };
    /**
     * Define the icon to show on overlay.
     */
    iconOverlay: string;
    /**
     * Define the text to show on overlay.
     */
    textOverlay: string;
    /**
     * Define the text to show on view image.
     */
    viewImageText: string;
    /**
     * Define the text to show on edit image.
     */
    editImageText: string;
    /**
     * Define the text to show on upload image.
     */
    uploadImageText: string;
    /**
     * Define the text to show on remove image.
     */
    removeImageText: string;
    /**
     * Host listner to know when user click outside component,
     * to close the dropdown and remove overlay.
     *
     * @param evt - The event dispatch for the host listner.
     */
    clickOut(evt: any): void;
    constructor(eRef: ElementRef);
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * This method detect the position of the mouse click,
     * and set top/left of the dropdown.
     *
     * @param evt - Detect mouse event.
     */
    onPictureClick(evt: MouseEvent): void;
    /**
     * This method detect when mouse leave the image.
     */
    onMouseLeavePicture(): void;
    /**
     *
     */
    onViewImage(): void;
    onEditImage(): void;
    /**
     * This method open the system file to choose a image.
     */
    onUploadImage(): void;
    onRemoveImage(evt: any): void;
    /**
     * The resulted cropped image is coming on "event" on different properties:
     * @ event.base64 if <uno-image-cropper />'s @Input() outputType is "base64"
     * @ event.file if <uno-image-cropper />'s @Input() outputType is "file"
     *
     * @param event
     */
    imageCropped(event: any): void;
    /**
     * User is satisfied with the cropped result of the image he/she uploaded from local machine
     * and is saying he/she wants this final croppped result to be saved (@ installation) as the pretended image
     */
    saveImgCropper(): void;
}
